@@ -7,13 +7,13 @@ from kikiutils.aes import AesCrypt
 
 
 class ServiceWebsocketConnection:
-    code = None
+    code: str = ''
 
     def __init__(self, aes: AesCrypt, websocket: WebSocket):
         self.aes = aes
         self.ws = websocket
 
-    async def send(self, event: str, *args, **kwargs):
+    async def emit(self, event: str, *args, **kwargs):
         await self.send_text(self.aes.encrypt([event, args, kwargs]))
 
     async def send_text(self, text: str):
@@ -86,7 +86,7 @@ class ServiceWebsockets:
             pass
 
         if connection.code:
-            self._del_connection(connection)
+            self._del_connection(group_name, connection)
 
     def on(self, event: str):
         """Register event handler."""
@@ -100,11 +100,11 @@ class ServiceWebsockets:
         return decorator
 
     async def send_to_all(self, event: str, *args, **kwargs):
-        text = self.aes.encrypt([event, args, kwargs])
+        data = self.aes.encrypt([event, args, kwargs])
 
         for group in self.connections.values():
             for c in group.values():
-                await c.send_text(text)
+                await c.send_text(data)
 
     async def send_to_group(
         self,
@@ -114,7 +114,7 @@ class ServiceWebsockets:
         **kwargs
     ):
         if group_name in self.connections:
-            text = self.aes.encrypt([event, args, kwargs])
+            data = self.aes.encrypt([event, args, kwargs])
 
             for c in self.connections[group_name].values():
-                await c.send_text(text)
+                await c.send_text(data)
